"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.coverageFolderName = void 0;

var _path = require("path");

var _toolLib = require("@kettil/tool-lib");

var _exec = _interopRequireDefault(require("../../cmd/exec"));

var _existFiles = _interopRequireDefault(require("../../cmd/existFiles"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const coverageFolderName = 'coverage';
exports.coverageFolderName = coverageFolderName;
const configFiles = ['jest.config.js', 'jest.config.ts'];
const options = ['updateSnapshot', 'runInBand', 'watch'];

const jest = async ({
  cwd,
  ci,
  log
}, props) => {
  const coverageFolder = (0, _path.join)(cwd, coverageFolderName);
  const files = await (0, _existFiles.default)(configFiles, cwd);

  if (files.length === 0) {
    throw new Error('Jest config file was not found');
  }

  const cmd = './node_modules/.bin/jest';
  const args = ['--colors', '--config', files[0]];

  if (typeof props.project === 'string') {
    args.push('--selectProjects', props.project);
  } else if ((0, _toolLib.isArray)(props.project)) {
    args.push('--selectProjects', ...props.project);
  }

  options.forEach(option => {
    if (props[option] === true) {
      args.push(`--${option}`);
    }
  });

  if (ci && props.coverage) {
    args.push('--ci');
    args.push('--silent');
    args.push('--coverage');
    args.push('--coverageDirectory', coverageFolder); // args.push('--coverageReporters', 'text');

    args.push('--coverageReporters', 'text-summary');
    args.push('--coverageReporters', 'json-summary');
  } else if (ci && !props.coverage) {
    args.push('--ci');
    args.push('--no-coverage');

    if (typeof props.project === 'string' && (0, _toolLib.isArray)(props.projectList) && props.projectList.length > 0) {
      const projectIndex = props.projectList.indexOf(props.project) + 1; // Also outputs the test result as JSON so that it
      // can be further interpreted (e.g. as a comment in PR/MR)

      args.push('--json');
      args.push('--outputFile', (0, _path.join)(coverageFolder, `jest-project-${projectIndex}-${props.project}-summary.json`));
    }
  } else if (!ci && !props.coverage) {
    args.push('--coverage');
    args.push('--coverageDirectory', coverageFolder);
    args.push('--coverageThreshold', '\'{"global":{"statements":0,"branches":0,"functions":0,"lines":0}}\'');
  }

  log.info('Run test');
  const {
    stdout
  } = await (0, _exec.default)({
    cmd,
    args,
    cwd,
    log,
    withInteraction: props.watch,
    withDirectOutput: ci
  });

  if (stdout.trim() !== '') {
    log.log('');
    log.log(stdout);
    log.log('');
  }
};

var _default = jest;
exports.default = _default;