"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.analyseServices = void 0;

var _path = require("path");

var _eslint = _interopRequireDefault(require("../actions/tools/eslint"));

var _prettier = _interopRequireWildcard(require("../actions/tools/prettier"));

var _tsc = _interopRequireDefault(require("../actions/tools/tsc"));

var _spinner = require("../cli/spinner");

var _access = _interopRequireDefault(require("../cmd/access"));

var _npmHookTask = _interopRequireDefault(require("./subTasks/npmHookTask"));

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const analyseServices = ['eslint', 'prettier', 'typescript'];
exports.analyseServices = analyseServices;

const isSelectedService = (value, service) => typeof value === 'undefined' || value === service;

const analyseTask = async (argv, {
  only,
  eslintFiles,
  prettierFiles
}) => {
  await (0, _npmHookTask.default)(argv, {
    task: 'analyse',
    type: 'pre'
  });
  const hasTypescriptConfig = await (0, _access.default)((0, _path.join)(argv.cwd, 'tsconfig.json'), 'readable');

  if (isSelectedService(only, 'prettier')) {
    const prettierOptions = {
      write: !argv.ci,
      extension: argv.ci ? _prettier.prettierExtensionCi : undefined,
      files: prettierFiles
    };
    await (0, _spinner.spinnerAction)((0, _prettier.default)(argv, prettierOptions), 'Prettier');
  }

  if (isSelectedService(only, 'eslint')) {
    const eslintOptions = {
      write: !argv.ci,
      files: eslintFiles
    };
    await (0, _spinner.spinnerAction)((0, _eslint.default)(argv, eslintOptions), 'ESLint');
  }

  if (isSelectedService(only, 'typescript')) {
    if (hasTypescriptConfig) {
      await (0, _spinner.spinnerAction)((0, _tsc.default)(argv, {
        mode: 'type-check'
      }), 'Typescript');
    } else {
      argv.log.info('Typing check is skipped (tsconfig.json was not found) ');
    }
  }

  await (0, _npmHookTask.default)(argv, {
    task: 'analyse',
    type: 'post'
  });
};

var _default = analyseTask;
exports.default = _default;