"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _promises = require("fs/promises");

var _path = require("path");

var _toolLib = require("@kettil/tool-lib");

var _config = _interopRequireDefault(require("../../cli/config"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const ignoreFolders = new Set(['shared', 'type']);
const specialFolders = ['unit', 'integration', 'e2e'];
const defaultCoverageProjects = ['unit', 'integration'];

const getTestProjects = async ({
  cwd
}, selectedProjects, withCoverage) => {
  const files = await (0, _promises.readdir)((0, _path.join)(cwd, 'tests'), {
    withFileTypes: true
  });
  const folders = files.filter(file => file.isDirectory() && !file.name.startsWith('.')).map(folder => folder.name).filter(folder => !ignoreFolders.has(folder)).sort();
  const projects = [...specialFolders.filter(folder => folders.includes(folder)), ...folders.filter(folder => !specialFolders.includes(folder))];

  if (selectedProjects === undefined || selectedProjects.length === 0) {
    if (withCoverage) {
      const configCoverageProjects = await (0, _config.default)(cwd, 'test.coverage.projects');
      return (0, _toolLib.isArray)(configCoverageProjects) && configCoverageProjects.length > 0 ? configCoverageProjects.filter(v => typeof v === 'string') : defaultCoverageProjects;
    }

    return projects;
  }

  const unknownProjects = selectedProjects.filter(v => !projects.includes(v));

  if (unknownProjects.length > 0) {
    throw new Error(`The following test project(s) are unknown: ${unknownProjects.join(', ')}`);
  }

  return projects.filter(v => selectedProjects.includes(v));
};

var _default = getTestProjects;
exports.default = _default;